

#include "reg24le1.h" 
#include "string.h"

/*
================================================================================
UART_Init:
    Initialize the UART
input     : BaudIndex, the index of the  baudrate of the UART, 0-7, 1200-115200
Output    : None
================================================================================
*/
code unsigned int UART_BAUD_TBL[7] = { 607, 816, 920, 972, 998, 1011, 1015 };
//0----6,,,--> 1200, 2400, 4800, 9600, 19200, 38400, 57600
void UART_Init( unsigned char BaudIndex )
{
	IEN0 &= ~( 1<<4 );				//Disable UART0 interrupt while initializeing
	S0CON = ( 1<<6 ) | ( 1<<4 );	//MODE1, Enable receive
	ADCON = 0x80;					//Enable baudrate generator
	PCON |= 0x80;					//mode1
	S0RELL = UART_BAUD_TBL[BaudIndex];
	S0RELH = UART_BAUD_TBL[BaudIndex] >> 8;
	IEN0 |= ( 1<<4 );				//Enable interrupt
    P0DIR |= ( 1<<6 );              //P0.6, RXD, set as input
    P0DIR &= ~( 1<<5 );             //P0.5, TXD, set as output
}
unsigned char TX_OK = 0;
static void UART0_ISR( void ) interrupt INTERRUPT_UART0
{
    if( S0CON & ( 1<<1 ) )
    {
        //TX ok
        S0CON &= ~( 1<<1 );
        TX_OK = 1;
    }
    else if( S0CON & ( 1<<0 ) )
    {
        //RX ok        
        S0CON &= ~( 1<<0 );
        P0DIR &= ~( 1<<2 );         //Set P0.2 as output
        P0 ^= ( 1<<2 );             //Turn on the LED
        S0BUF = S0BUF;
    }
}

void UART0_SendBuff( unsigned char *buff, unsigned char size )
{  
    while( size -- )
    {
        TX_OK = 0;
        S0BUF = *buff ++;
        while( TX_OK == 0 );
    }
    TX_OK = 0;
}

void UART0_SendStr( char* str )
{
    UART0_SendBuff( ( unsigned char* ) str, strlen( str ) );
}

void main( void )
{
    CLKCTRL = ( CLKCTRL | 0x80 ) & ~0x08;

    UART_Init( 3 );    //baudrate = 9600
    EA = 1;
    UART0_SendStr( "nRF24LE1 UART Test Start!\r\n" );
    while( 1 );
}