
#include "reg24le1.h"
#include "main.h"
#include "nRF24L01.h"

/*
================================================================================
SPI_Exchange :
    Exchange a byte via the MCU
input     : dt, the byte to be sent
Output    : The byte read from the slaver
================================================================================
*/
INT8U SPI_ExchangeByte( INT8U dt )
{
    SPIRDAT = dt;
    while( !( SPIRSTAT & 0x02  ) );
    return SPIRDAT;
}

//RF interrupt
INT8U rf_flag = 0;
void RF_IRQ( void )	interrupt INTERRUPT_RFIRQ
{
	INT8U i = L01_ReadIRQSource( );
    	
	if( i & ( 1<<RX_DR ) )		//Received data
	{
        rf_flag |= ( 1<<1 );
	}
	if( i & ( 1<<TX_DS ) )		//Send data OK
	{
        rf_flag |= ( 1<<2 );
	}
	if( i & ( 1<<MAX_RT ) )		//Send data fail
	{
        rf_flag |= ( 1<<3 );
	}
	L01_ClearIRQ( IRQ_ALL );   
}
/*
================================================================================
UART_Init:
    Initialize the UART
input     : BaudIndex, the index of the  baudrate of the UART, 0-7, 1200-115200
Output    : None
================================================================================
*/
code unsigned int UART_BAUD_TBL[7] = { 607, 816, 920, 972, 998, 1011, 1015 };
//0----6,,,--> 1200, 2400, 4800, 9600, 19200, 38400, 57600
void UART_Init( unsigned char BaudIndex )
{
	IEN0 &= ~( 1<<4 );				//Disable UART0 interrupt while initializeing
	S0CON = ( 1<<6 ) | ( 1<<4 );	//MODE1, Enable receive
	ADCON = 0x80;					//Enable baudrate generator
	PCON |= 0x80;					//mode1
	S0RELL = UART_BAUD_TBL[BaudIndex];
	S0RELH = UART_BAUD_TBL[BaudIndex] >> 8;
	IEN0 |= ( 1<<4 );				//Enable interrupt
    P0DIR |= ( 1<<6 );              //P0.6, RXD, set as input
    P0DIR &= ~( 1<<5 );             //P0.5, TXD, set as output
}
unsigned char TX_OK = 0;
static void UART0_ISR( void ) interrupt INTERRUPT_UART0
{
    if( S0CON & ( 1<<1 ) )
    {
        //TX ok
        S0CON &= ~( 1<<1 );
        TX_OK = 1;
    }
    else if( S0CON & ( 1<<0 ) )
    {
        //RX ok        
        S0CON &= ~( 1<<0 );
    }
}

void UART0_SendBuff( unsigned char *buff, unsigned char size )
{  
    while( size -- )
    {
        TX_OK = 0;
        S0BUF = *buff ++;
        while( TX_OK == 0 );
    }
    TX_OK = 0;
}
void UART0_SendStr( char* str )
{
    UART0_SendBuff( ( unsigned char* ) str, strlen( str ) );
}
int main( void )
{
    INT16U itmp;
    
    CLKCTRL = ( CLKCTRL | 0x80 ) & ~0x08;
    P0DIR = 0;

    RFCON = 0x07;
    RFCE = 0;
  	RFCKEN = 1;                                 		// RFʱ
  	RF = 1;                                    		    // RFж
    for( itmp = 0; itmp < 30000; itmp ++ );  

    UART_Init( 3 );                 //9600      
    EA = 1;
    UART0_SendStr( "nRF24LE1 TX test start!\r\n" );
    RFCE = 1;
    while( 1 )
    {
        P0 |= ( 1<<0 );
        for( itmp = 0; itmp < 50000; itmp ++ );
        for( itmp = 0; itmp < 50000; itmp ++ );
        L01_Init( );	              	//Initialize the internal 24L01P    
        L01_SetTXMode( );               //Set as TX mode
        L01_FlushTX( );
        L01_FlushRX( );
        rf_flag = 0;
        L01_WriteTXPayload_Ack( ( INT8U* )"12345ABCDE\r\n", 12 );
        RFCE = 1;
        while( rf_flag == 0 );
        if( rf_flag & ( 1<<1 ) )  //received
        {

        }
        if( rf_flag & ( 1<<2 ) )
        {
            P0 ^= ( 1<<2 ) | ( 1<<3 ) | ( 1<<4 ); 
            UART0_SendStr( "Send OK!\r\n" );  
        }
        if( rf_flag & ( 1<<3 ) )
        {
            UART0_SendStr( "Send Error!\r\n" );
        }
        RFCE = 0;
        rf_flag = 0;
        
    }
}